@@ -33,7 +33,6 @@
 
 #include "imagelib/kpColor.h"
 
-#include <KIconLoader>
 #include <KLocalizedString>
 
 #include <QContextMenuEvent>
@@ -49,7 +48,7 @@ kpTransparentColorCell::kpTransparentColorCell (QWidget *parent)
                    QSizePolicy::Fixed/*vertical*/);
     setFrameStyle (QFrame::Panel | QFrame::Sunken);
 
-    m_pixmap = UserIcon (QStringLiteral("color_transparent_26x26"));
+    m_pixmap = QStringLiteral(":/icons/color_transparent_26x26");
 
     this->setToolTip( i18n ("Transparent"));
 }
@@ -69,7 +68,7 @@ QSize kpTransparentColorCell::sizeHint () const
 void kpTransparentColorCell::mousePressEvent (QMouseEvent * /*e*/)
 {
     // Eat press so that we own the mouseReleaseEvent().
-    // [http://blogs.qtdeveloper.net/archives/2006/05/27/mouse-event-propagation/]
+    // [https://www.qt.io/blog/2006/05/27/mouse-event-propagation]
     //
     // However, contrary to that blog, it doesn't seem to be needed?
 }
